### R code from vignette source 'pcalgDoc.Rnw'

###################################################
### code chunk number 1: preliminaries
###################################################
options(SweaveHooks=
        list(fig=function() par(mar=c(5.1, 4.1, 1.1, 2.1))),
        width = 75,
        digits = 5,
        prompt = "R> ")


###################################################
### code chunk number 2: def-gmG (eval = FALSE)
###################################################
## set.seed(40)
## p <- 8
## n <- 5000
## gGtrue <- randomDAG(p, prob = 0.3)
## gmG <- list(x = rmvDAG(n, gGtrue), g = gGtrue)


###################################################
### code chunk number 3: exIntro1
###################################################
library("pcalg")
data("gmG")


###################################################
### code chunk number 4: Iplot (eval = FALSE)
###################################################
## stopifnot(require(Rgraphviz))# needed for all our graph plots
## par(mfrow = c(1,2))
## plot(gmG$g, main = "")
## plot(pc.fit, main = "")


###################################################
### code chunk number 5: exIntroPlot
###################################################
suffStat <- list(C = cor(gmG$x), n = nrow(gmG$x))
pc.fit <- pc(suffStat, indepTest = gaussCItest,
             p = ncol(gmG$x), alpha = 0.01)
stopifnot(require(Rgraphviz))# needed for all our graph plots
par(mfrow = c(1,2))
plot(gmG$g, main = "")
plot(pc.fit, main = "")


###################################################
### code chunk number 6: exIntroPlot
###################################################
stopifnot(require(Rgraphviz))# needed for all our graph plots
par(mfrow = c(1,2))
plot(gmG$g, main = "")
plot(pc.fit, main = "")


###################################################
### code chunk number 7: exIntro2
###################################################
ida(1, 6, cov(gmG$x), pc.fit@graph)


###################################################
### code chunk number 8: exIntro3
###################################################
idaFast(1, c(4,5,6), cov(gmG$x), pc.fit@graph)


###################################################
### code chunk number 9: skeleton-args
###################################################
showF <- function(f, width = 82) {
    ## 'width': larger than default on purpose:
    nam <- deparse(substitute(f))
    stopifnot(is.function(f))
    attr(f, "source") <- NULL # if ...
    ll <- capture.output(str(f, width=width))
    ll[1] <- sub("function *", nam, ll[1])
    writeLines(ll)
}
showF(skeleton)


###################################################
### code chunk number 10: skelExpl1Plot
###################################################
require("pcalg")
data("gmG")
suffStat <- list(C = cor(gmG$x), n = nrow(gmG$x))
pc.fit <- skeleton(suffStat, indepTest = gaussCItest,
                   p = ncol(gmG$x), alpha = 0.01)
par(mfrow = c(1,2))
plot(gmG$g, main = "")
plot(pc.fit, main = "")


###################################################
### code chunk number 11: skelExp2Plot
###################################################
data("gmD")
suffStat <- list(dm = gmD$x, nlev = c(3,2,3,4,2), adaptDF = FALSE)
skel.fit <- skeleton(suffStat, indepTest = disCItest,
                     p = ncol(gmD$x), alpha = 0.01)
par(mfrow = c(1,2))
plot(gmD$g, main = "")
plot(skel.fit, main = "")


###################################################
### code chunk number 12: pc-args
###################################################
showF(pc)


###################################################
### code chunk number 13: pcExpl-plot
###################################################
suffStat <- list(C = cor(gmG$x), n = nrow(gmG$x))
pc.fit <- pc(suffStat, indepTest=gaussCItest, p = ncol(gmG$x), alpha = 0.01)
par(mfrow = c(1,2))
plot(gmG$g, main = "")
plot(pc.fit, main = "")


###################################################
### code chunk number 14: fci-args
###################################################
showF(fci)


###################################################
### code chunk number 15: def-fciExpl-plot (eval = FALSE)
###################################################
## data("gmL")
## suffStat1 <- list(C = cor(gmL$x), n = nrow(gmL$x))
## pag.est <- fci(suffStat1, indepTest= gaussCItest,
##                p = ncol(gmL$x), alpha = 0.01, labels = as.character(2:5))
## par(mfrow = c(1,2))
## plot(gmL$g, main = "")
## plot(pag.est)


###################################################
### code chunk number 16: fciExpl-plot
###################################################
data("gmL")
suffStat1 <- list(C = cor(gmL$x), n = nrow(gmL$x))
pag.est <- fci(suffStat1, indepTest= gaussCItest,
               p = ncol(gmL$x), alpha = 0.01, labels = as.character(2:5))
par(mfrow = c(1,2))
plot(gmL$g, main = "")
plot(pag.est)


###################################################
### code chunk number 17: def-gmI (eval = FALSE)
###################################################
## set.seed(123)
## p <- 7
## n <- 10000
## myDAG <- randomDAG(p, prob = 0.2)
## datI <- rmvDAG(n, myDAG)
## gmI <- list(x = datI, g = myDAG)


###################################################
### code chunk number 18: idaExpl1
###################################################
data("gmI")
suffStat <- list(C = cor(gmI$x), n = nrow(gmI$x))
pc.fit <- pc(suffStat, indepTest=gaussCItest,
             p = ncol(gmI$x), alpha = 0.01)


###################################################
### code chunk number 19: idaExpl2
###################################################
par(mfrow = c(1,2))
plot(gmI$g, main = "")
plot(pc.fit, main = "")


###################################################
### code chunk number 20: idaExpl3
###################################################
am.pdag <- wgtMatrix(pc.fit@graph)
ad <- allDags(am.pdag, am.pdag, NULL)
gDag <- vector("list", nrow(ad))
for (i in 1:nrow(ad)) gDag[[i]] <- as(matrix(ad[i, ], 7, 7), "graphNEL")
par(mfrow = c(3,2))
for (i in 1:6) plot(gDag[[i]], main = paste("DAG",i))


###################################################
### code chunk number 21: plot-6DAGS
###################################################
sfsmisc::mult.fig(6)
for (i in 1:6) plot(gDag[[i]], main = paste("DAG",i))


###################################################
### code chunk number 22: idaExpl4
###################################################
ida(2, 5, cov(gmI$x), pc.fit@graph, method = "global", verbose = FALSE)


###################################################
### code chunk number 23: ida-args
###################################################
showF(ida)


###################################################
### code chunk number 24: idaExpl5
###################################################
ida(2,5, cov(gmI$x), pc.fit@graph, method = "local")


###################################################
### code chunk number 25: idaFast-args
###################################################
showF(idaFast)


###################################################
### code chunk number 26: ida-idaFast
###################################################
data("gmI")
suffStat <- list(C = cor(gmI$x), n = nrow(gmI$x))
pc.fit <- pc(suffStat, indepTest=gaussCItest, p=ncol(gmI$x), alpha = 0.01)

(eff.est1 <- ida(2,5, cov(gmI$x), pc.fit@graph, method="local"))
(eff.est2 <- ida(2,6, cov(gmI$x), pc.fit@graph, method="local"))
(eff.est3 <- ida(2,7, cov(gmI$x), pc.fit@graph, method="local"))

(eff.estF <- idaFast(2, c(5,6,7), cov(gmI$x), pc.fit@graph))


###################################################
### code chunk number 27: turn-off-plus
###################################################
options(continue = " ") # MM: so we don't get the "+ " continuation lines


###################################################
### code chunk number 28: myCItest
###################################################
myCItest <- function(x,y,S, suffStat) {
  if (length(S) == 0) {
    x. <- suffStat[,x]
    y. <- suffStat[,y]
  } else {
    rxy <- resid(lm.fit(y= suffStat[,c(x,y)], x= cbind(1, suffStat[,S])))
    x. <- rxy[,1];  y. <- rxy[,2]
  }
  cor.test(x., y.)$p.value
}


###################################################
### code chunk number 29: gaussCItest-ex
###################################################
suffStat <- list(C = cor(gmG$x), n = 5000)
pc.fit <- pc(suffStat, indepTest=gaussCItest, p = 8, alpha = 0.01)


###################################################
### code chunk number 30: myCItest-def-plot (eval = FALSE)
###################################################
## pc.myfit <- pc(suffStat = gmG$x, indepTest = myCItest,
##                p = 8, alpha = 0.01)
## par(mfrow = c(1,2))
## plot(pc.fit, main = "")
## plot(pc.myfit, main = "")


###################################################
### code chunk number 31: myCItest-ex-plot
###################################################
pc.myfit <- pc(suffStat = gmG$x, indepTest = myCItest,
               p = 8, alpha = 0.01)
par(mfrow = c(1,2))
plot(pc.fit, main = "")
plot(pc.myfit, main = "")


###################################################
### code chunk number 32: time-tests (eval = FALSE)
###################################################
## system.time(for(i in 1:10)
##             pc.fit <- pc(suffStat, indepTest=gaussCItest, p = 8, alpha = 0.01))
##       ##  User      System verstrichen
##       ## 0.593       0.000       0.594
## system.time(for(i in 1:10)
##             pc.myfit <- pc(gmG$x,  indepTest = myCItest,  p = 8, alpha = 0.01))
## ## Using  resid(lm(..)) twice:
##      ##   User      System verstrichen
##      ## 44.864       0.007      44.937
## ## Using resid(lm.fit(..)):
##      ## 10.550       0.067      10.632


###################################################
### code chunk number 33: sessionInfo
###################################################
toLatex(sessionInfo())


